@@ -7,7 +7,7 @@ import sys
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 
-__version__ = '0.0.8'
+__version__ = '0.1'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
@@ -265,7 +265,7 @@ def main():
     else:
         poller = poll()
         poller.register(sys.stdin, POLLIN)
-        ret = poller.poll(0.5)
+        ret = poller.poll(300)
         if len(ret) == 1 and ret[0][1] & POLLIN:
             helptext = sys.stdin.read()
         else:
